@@ -8,5 +8,5 @@ class ApiCost(ApiBase):
         return self.build_route(
             "spaces/{space_name}/cost/breakdown?criteria={criteria}&from={frm}&to={until}".format(**locals()))
 
-    def usage(self, space_name: str, date: datetime):
-        return self.build_route("spaces/{space_name}/cost/usage?date={date}".format(**locals()))
+    def usage(self, space_name: str, date: datetime, timezone: str = ''):
+        return self.build_route("spaces/{space_name}/cost/usage?date={date}&timezone={timezone}".format(**locals()))
