@@ -8,6 +8,7 @@ from gateways.apis.api_catalog import ApiCatalog
 from gateways.apis.api_cost import ApiCost
 from gateways.apis.api_debugging import ApiDebugging
 from gateways.apis.api_oauth_redirect import ApiOauthRedirect
+from gateways.apis.api_parameter_store import ParameterStore
 from gateways.apis.api_production import ApiProduction
 from gateways.apis.api_qualiy import ApiQualiY
 from gateways.apis.api_sandbox import ApiSandbox
@@ -34,3 +35,4 @@ class ApiRoot:
         self.token = ApiToken(api_address, version)
         self.cost = ApiCost(api_address, version)
         self.debugging = ApiDebugging(api_address, version)
+        self.parameterStore = ParameterStore(api_address, version)
