@@ -9,7 +9,13 @@ class ApiSpaces(ApiBase):
         return self.build_route("spaces/{space_name}".format(**locals()))
 
     def get_images(self, space_name: str, cloud_account_name: str, region_id: str):
-        return self.build_route("spaces/{space_name}/cloud_accounts/{cloud_account_name}/regions/{region_id}/private_images"
+        return self.build_route("spaces/{space_name}/cloud_accounts/AWS/{cloud_account_name}/regions/{"
+                                "region_id}/private_images"
+                                .format(**locals()))
+
+    def get_instance_types(self, space_name: str, cloud_account_name: str, region_id: str):
+        return self.build_route("spaces/{space_name}/cloud_accounts/AWS/{cloud_account_name}/regions/{"
+                                "region_id}/instance_types"
                                 .format(**locals()))
 
     def space_users(self, space_name: str):
