@@ -1076,8 +1076,11 @@ class AwsSsmValue(ParameterStoreValue):
 
 
 class ParameterStoreItem:
-    def __init__(self, name: str, origin: str, value: ParameterStoreValue, description: str = ''):
+    def __init__(self, name: str, origin: str, value: ParameterStoreValue, description: str = '', modified_by=None,
+                 last_modified=None):
         self.name = name
         self.origin = origin
         self.description = description
         self.value = value
+        self.last_modified = last_modified
+        self.modified_by = modified_by
